@@ -1,25 +1,21 @@
+//! Efficient decimal integer formatting.
+//!
 //! # Safety
 //!
 //! This uses `CStr::from_bytes_with_nul_unchecked` and
 //! `str::from_utf8_unchecked`on the buffer that it filled itself.
 #![allow(unsafe_code)]
 
-use crate::ffi::ZStr;
-use crate::imp::fd::{AsFd, AsRawFd};
-#[cfg(feature = "std")]
-use core::fmt;
+use crate::backend::fd::{AsFd, AsRawFd};
+use crate::ffi::CStr;
 use core::fmt::Write;
 use itoa::{Buffer, Integer};
-#[cfg(feature = "std")]
-use std::ffi::{CStr, OsStr};
-#[cfg(feature = "std")]
-#[cfg(unix)]
+#[cfg(all(feature = "std", unix))]
 use std::os::unix::ffi::OsStrExt;
-#[cfg(feature = "std")]
-#[cfg(target_os = "wasi")]
+#[cfg(all(feature = "std", target_os = "wasi"))]
 use std::os::wasi::ffi::OsStrExt;
 #[cfg(feature = "std")]
-use std::path::Path;
+use {core::fmt, std::ffi::OsStr, std::path::Path};
 
 /// Format an integer into a decimal `Path` component, without constructing a
 /// temporary `PathBuf` or `String`.
@@ -28,9 +24,11 @@ use std::path::Path;
 ///
 /// # Example
 ///
-/// ```rust
+/// ```
+/// # #[cfg(feature = "path")]
 /// use rustix::path::DecInt;
 ///
+/// # #[cfg(feature = "path")]
 /// assert_eq!(
 ///     format!("hello {}", DecInt::new(9876).as_ref().display()),
 ///     "hello 9876"
@@ -63,42 +61,30 @@ impl DecInt {
         Self::new(fd.as_fd().as_raw_fd())
     }
 
-    /// Return the raw byte buffer.
-    #[inline]
-    pub fn as_bytes(&self) -> &[u8] {
-        &self.buf[..self.len]
-    }
-
     /// Return the raw byte buffer as a `&str`.
     #[inline]
     pub fn as_str(&self) -> &str {
-        // # Safety
-        //
-        // `DecInt` always holds a formatted decimal number, so it's always
-        // valid UTF-8.
+        // SAFETY: `DecInt` always holds a formatted decimal number, so it's
+        // always valid UTF-8.
         unsafe { core::str::from_utf8_unchecked(self.as_bytes()) }
     }
 
-    /// Return the raw byte buffer as a `&ZStr`.
-    #[inline]
-    pub fn as_z_str(&self) -> &ZStr {
-        let bytes_with_nul = &self.buf[..=self.len];
-        debug_assert!(ZStr::from_bytes_with_nul(bytes_with_nul).is_ok());
-        // Safety: `self.buf` holds a single decimal ASCII representation and
-        // at least one extra NUL byte.
-        unsafe { ZStr::from_bytes_with_nul_unchecked(bytes_with_nul) }
-    }
-
     /// Return the raw byte buffer as a `&CStr`.
-    #[cfg(feature = "std")]
     #[inline]
     pub fn as_c_str(&self) -> &CStr {
         let bytes_with_nul = &self.buf[..=self.len];
         debug_assert!(CStr::from_bytes_with_nul(bytes_with_nul).is_ok());
-        // Safety: `self.buf` holds a single decimal ASCII representation and
+
+        // SAFETY: `self.buf` holds a single decimal ASCII representation and
         // at least one extra NUL byte.
         unsafe { CStr::from_bytes_with_nul_unchecked(bytes_with_nul) }
     }
+
+    /// Return the raw byte buffer.
+    #[inline]
+    pub fn as_bytes(&self) -> &[u8] {
+        &self.buf[..self.len]
+    }
 }
 
 struct DecIntWriter(DecInt);
